.. _contributing:

Contributing
============

Thank you for wanting to contribute to this library! We will try to make this an easy process for you.

**If you find errors in the codebase:**

1. Submit an issue at the `pvops issues page <https://github.com/tgunda/pvops/issues>`_

**If you would like to contribute:**

2. Create a pull request (PR) or help with other PRs which are in the library by referencing `pvops PR page <https://github.com/tgunda/pvops/pulls>`_. Pull requests should contain code that follows the PEP8 python code style.

**If you are confused:**

3. Feel free to reach out to the package maintainer, as found in setup.py. 